import static org.junit.Assert.*;

import org.junit.Test;



public class DateTest {

	@Test
	public void testIncrementSimple() {
		Date d = new Date(1,1,2012);
		d.increment();
		assertEquals(d.getDay(), 2);
		assertEquals(d.getMonth(), 1);
		assertEquals(d.getYear(), 2012);
	}
	
	@Test
	public void testIncrementEndMonth() {
		Date d = new Date(31,1,2012);
		d.increment();
		assertEquals(d.getDay(), 1);
		assertEquals(d.getMonth(), 2);
		assertEquals(d.getYear(), 2012);
	}
	
	@Test
	public void testIncrementEndYear() {
		Date d = new Date(31,12,2012);
		d.increment();
		assertEquals(d.getDay(), 1);
		assertEquals(d.getMonth(), 1);
		assertEquals(d.getYear(), 2013);
	}

	@Test(expected=RuntimeException.class)
	public void testConstructorInvalidMonth(){
		new Date(1,-1,2012);		
	}
	
	@Test(expected=RuntimeException.class)
	public void testConstructorInvalidMonth1(){
		new Date(1,0,2012);		
	}
	
	@Test(expected=RuntimeException.class)
	public void testConstructorInvalidMonth2(){
		new Date(1,13,2012);		
	}
	
	@Test
	public void testConstructorValid(){
		Date d = new Date(16,2,2012);
		assertNotNull(d);
	}

	@Test
	public void testFebruaryLeapYear2012()
	{
		Date d = new Date(29,02,2012); 
		assertNotNull(d);
		d.increment();
		assertEquals(d.getDay(), 1);
		assertEquals(d.getMonth(), 3);
	}
	
	@Test
	public void testFebruaryLeapYear2000()
	{
		Date d = new Date(29,02,2000); 
		assertNotNull(d);
	}
	
	@Test(expected=RuntimeException.class)
	public void testFebruaryLeapYear1900()
	{
		new Date(29,02,1900); 
	}
	
	@Test
	public void testFebruary2012Increment()
	{
		Date d = new Date(29,02,2012); 
		d.increment();
		assertEquals(d.getDay(), 1);
		assertEquals(d.getMonth(), 3);
	}
	
	@Test
	public void testFebruary1900Increment()
	{
		Date d = new Date(28,02,1900); 
		d.increment();
		assertEquals(d.getDay(), 1);
		assertEquals(d.getMonth(), 3);
	}
	
	/* TODO : ajouter des tests :
	 *   * Si on change l'anne d'une date d'une anne bisextile 
	 *     vers une anne non bisextile, il pourrait y avoir un problme
	 *     fin fvrier
	 *   * Idem si on change le mois.  
	 *   * Tester dayOfYear() (faire un cas galement les annes bisextiles)
	 *   * Tester dayOfWeek()
	 *   * Tester toString() (beaucoup de tests)
	 *   * Tester la mthode writeToFile. 
	 */
	 
	
}
